==> alipay-sdk-python-3.7.78.tar.gz: alipay-sdk-python-3.7.78/alipay/aop/api/domain/AlipayUserDtbankcustChannelvoucherSendModel.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserDtbankcustChannelvoucherSendModel(object):

    def __init__(self):
        self._activity_id = None
        self._logon_id = None
        self._open_id = None
        self._out_biz_no = None
        self._phone_id = None
        self._user_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def phone_id(self):
        return self._phone_id

    @phone_id.setter
    def phone_id(self, value):
        self._phone_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.phone_id:
            if hasattr(self.phone_id, 'to_alipay_dict'):
                params['phone_id'] = self.phone_id.to_alipay_dict()
            else:
                params['phone_id'] = self.phone_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserDtbankcustChannelvoucherSendModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'phone_id' in d:
            o.phone_id = d['phone_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o

==> alipay-sdk-python-3.7.708.tar.gz: alipay-sdk-python-3.7.708/alipay/aop/api/domain/AlipayUserDtbankcustChannelvoucherSendModel.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SpecifyUserInfo import SpecifyUserInfo


class AlipayUserDtbankcustChannelvoucherSendModel(object):

    def __init__(self):
        self._activity_id = None
        self._logon_id = None
        self._open_id = None
        self._out_biz_no = None
        self._phone_id = None
        self._specify_user_info = None
        self._user_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def phone_id(self):
        return self._phone_id

    @phone_id.setter
    def phone_id(self, value):
        self._phone_id = value
    @property
    def specify_user_info(self):
        return self._specify_user_info

    @specify_user_info.setter
    def specify_user_info(self, value):
        if isinstance(value, SpecifyUserInfo):
            self._specify_user_info = value
        else:
            self._specify_user_info = SpecifyUserInfo.from_alipay_dict(value)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.phone_id:
            if hasattr(self.phone_id, 'to_alipay_dict'):
                params['phone_id'] = self.phone_id.to_alipay_dict()
            else:
                params['phone_id'] = self.phone_id
        if self.specify_user_info:
            if hasattr(self.specify_user_info, 'to_alipay_dict'):
                params['specify_user_info'] = self.specify_user_info.to_alipay_dict()
            else:
                params['specify_user_info'] = self.specify_user_info
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserDtbankcustChannelvoucherSendModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'phone_id' in d:
            o.phone_id = d['phone_id']
        if 'specify_user_info' in d:
            o.specify_user_info = d['specify_user_info']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o
